summaryrefslogtreecommitdiff
path: root/test/unit/util/configuration_black.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'test/unit/util/configuration_black.cpp')
-rw-r--r--test/unit/util/configuration_black.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/unit/util/configuration_black.cpp b/test/unit/util/configuration_black.cpp
index 44ae8c04b..a7c5c2703 100644
--- a/test/unit/util/configuration_black.cpp
+++ b/test/unit/util/configuration_black.cpp
@@ -9,15 +9,15 @@
** All rights reserved. See the file COPYING in the top-level source
** directory for licensing information.\endverbatim
**
** \brief Black box testing of CVC4::Configuration.
**
** Black box testing of CVC4::Configuration.
**/
#include "base/configuration.h"
#include "test.h"
-namespace CVC4 {
+namespace CVC5 {
namespace test {
class TestUtilBlackConfiguration : public TestInternal
@@ -96,4 +96,4 @@ TEST_F(TestUtilBlackConfiguration, about)
Configuration::about();
}
} // namespace test
-} // namespace CVC4
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -9,15 +9,15 @@
** directory for licensing information.\endverbatim
**
- ** \brief Black box testing of CVC4::Configuration.
+ ** \brief Black box testing of CVC5::Configuration.
**
@@ -9,15 +9,15 @@
**
- ** Black box testing of CVC4::Configuration.
+ ** Black box testing of CVC5::Configuration.
**/
#include "base/configuration.h"